# Changelog

<!--next-version-placeholder-->

## v2.5.0 (2021-05-17)
### Feature
* Migration to pydriller>=2.0 ([`a3b553f`](https://github.com/F-Secure/pytest-rts/commit/a3b553fcc9966c421fe8d3313fb2d41ec5230926))

### Documentation
* Rewrite tutorial ([`7c3e98d`](https://github.com/F-Secure/pytest-rts/commit/7c3e98dc2ffa5cb682be84ef3801bffa19f83f0e))
* Add tutorial and images ([`eb2c717`](https://github.com/F-Secure/pytest-rts/commit/eb2c7170b362c25ebac64314ea985699e615e14d))
* Switched to non-recursive test targets call ([`544f4ac`](https://github.com/F-Secure/pytest-rts/commit/544f4ac2729c073361b143b6db4938aaf950458c))
* Fixed Makefile example ([`2753568`](https://github.com/F-Secure/pytest-rts/commit/27535689a66ac621ac40b494e572f0a88aa6b9f1))
* Add cov-threshold tutorial ([`497ceb9`](https://github.com/F-Secure/pytest-rts/commit/497ceb951b72691bd210bfc6724c63889d88475f))

## v2.4.0 (2021-03-31)
### Feature
* Added handling of lines without mapping ([`d5dd6f5`](https://github.com/F-Secure/pytest-rts/commit/d5dd6f56eed03dcda03513e3c1210fdbc4b2932f))

### Fix
* Linter errors ([`bba133d`](https://github.com/F-Secure/pytest-rts/commit/bba133d1392e3b57cd3e530d5ee86ff25a219a6e))
* Linter errors ([`030bc32`](https://github.com/F-Secure/pytest-rts/commit/030bc32ac0191a71aa8fdfe88abae5a77de24fc4))

### Documentation
* Note about intersection and surroundings algorithm ([`f303ef8`](https://github.com/F-Secure/pytest-rts/commit/f303ef8b68b4380877fe9089ce5e7f4c3aed6a5a))

## v2.3.0 (2021-03-29)
### Feature
* Rts from changes between commits ([`13b490b`](https://github.com/F-Secure/pytest-rts/commit/13b490b957878412c8463650262e8f9784b624a4))

### Documentation
* Clarify change detection in readme ([`bb899cc`](https://github.com/F-Secure/pytest-rts/commit/bb899cc7f14cf21fb6702bdbb8249ced24d59958))
* Added missing env variable definition ([`a395403`](https://github.com/F-Secure/pytest-rts/commit/a3954034a53ecbf0cae5a3c237798dde38c332c2))
* Styling ([`323e19d`](https://github.com/F-Secure/pytest-rts/commit/323e19d14e7fc6f881ac4ed14c681767ff236e44))
* Styling ([`dfcfbe7`](https://github.com/F-Secure/pytest-rts/commit/dfcfbe7103457baf0144d6f819c3a61819192d47))
* Added example of Makefile ([`f2cd489`](https://github.com/F-Secure/pytest-rts/commit/f2cd489284ba951ab0206eadb67754e4f42db1a6))
* Update functionality description ([`d65aa12`](https://github.com/F-Secure/pytest-rts/commit/d65aa1204c2e5cb2e45b81a21cf2806c14a4fb66))
* Mention committed changes flag ([`a0c26cc`](https://github.com/F-Secure/pytest-rts/commit/a0c26cc96f9735f39cc846e7dafb043e48462259))
* Added --cov-config flag to init section ([`3807a30`](https://github.com/F-Secure/pytest-rts/commit/3807a30a22f902cf48e0739456655021b2755d96))

## v2.2.0 (2021-03-24)
### Feature
* Run tests from changes in workdir ([`5836afd`](https://github.com/F-Secure/pytest-rts/commit/5836afd07b04f005123c4d0d85c5920c7b61c7ea))

### Documentation
* Mention relative files configuration ([`07104f8`](https://github.com/F-Secure/pytest-rts/commit/07104f833633426aebaef0346c1b867422b45eec))
* Fixed initialization section ([`d093abb`](https://github.com/F-Secure/pytest-rts/commit/d093abb03b169b47e5a09d3d236d36ae36575b79))
* Added troubleshooting section ([`d03881e`](https://github.com/F-Secure/pytest-rts/commit/d03881e891b4f471b748ad5174698ed5641d2965))
* Updated usage instructions and removed outdated files ([`c8639e1`](https://github.com/F-Secure/pytest-rts/commit/c8639e1f83554bfbf7d07d1ffa72e62a05508232))

## v2.1.0 (2021-03-18)
### Feature
* Run new tests based on pytest-cov ([`7d40a75`](https://github.com/F-Secure/pytest-rts/commit/7d40a752aa69b9d16fbd0927fd4ded626c1355be))
* Start integrating to pytest-cov ([`af328ba`](https://github.com/F-Secure/pytest-rts/commit/af328bac2c439ee2daed12a9f1a7c8d0d058355c))
* Handle usage in non-git directory ([`8ad080b`](https://github.com/F-Secure/pytest-rts/commit/8ad080be7eb31b96e1047a4aadabe9fe1a944085))
* Create a pytest plugin ([#67](https://github.com/F-Secure/pytest-rts/issues/67)) ([`1ed34e3`](https://github.com/F-Secure/pytest-rts/commit/1ed34e3f6591f627f93dbacad213236f08237258))

### Fix
* Fix crash in test function runtimes ([`ad4c1f3`](https://github.com/F-Secure/pytest-rts/commit/ad4c1f3820a72bf2b9cbc8583c94bba6d2b2dcc2))
* Minor ([`891c743`](https://github.com/F-Secure/pytest-rts/commit/891c743332cf7c5248f6ec1b28140c4381a72ef6))
* Pypi long description ([`efb1c37`](https://github.com/F-Secure/pytest-rts/commit/efb1c3734f4b04f1e2e3dd6d677957fbe2507a4c))
* Pypi upload ([`f82e20c`](https://github.com/F-Secure/pytest-rts/commit/f82e20c43ec2936531e7a661560e8e98f089f164))
* Pypi upload ([`537d270`](https://github.com/F-Secure/pytest-rts/commit/537d2706a599455e40e6836b4bd3a308ae36160b))
* Pypi upload ([`d7778c8`](https://github.com/F-Secure/pytest-rts/commit/d7778c8b23777411b288af2a739e0f3e3ab3b7e6))
* Pypi upload ([`0f7339c`](https://github.com/F-Secure/pytest-rts/commit/0f7339c54dee32595280b42b118f06145067c29f))
* Merge branch 'master' of github.com:F-Secure/pytest-rts ([`97ab69d`](https://github.com/F-Secure/pytest-rts/commit/97ab69de2ce6447b638978017ba74a3ab9db94c8))
* Pypi upload ([`c6ba5bc`](https://github.com/F-Secure/pytest-rts/commit/c6ba5bc66c4969ea9f432b275c209a26a7d2c2cf))
* Pypi upload ([`7cde1be`](https://github.com/F-Secure/pytest-rts/commit/7cde1be414b980ecb5fb45eac24d7696aacf0b28))
* Rename selection file to prevent test discovery ([`b80f30a`](https://github.com/F-Secure/pytest-rts/commit/b80f30a6e29060f1b9769d01ec61760a49d2f977))
* Linter errors ([`b0f2ac0`](https://github.com/F-Secure/pytest-rts/commit/b0f2ac04937d3a36ba9697001949fb9cc12946c9))
* Track code in __init__.py files ([`ab89c7b`](https://github.com/F-Secure/pytest-rts/commit/ab89c7b9eb98435c0ab00cf1a43393f907126743))

### Documentation
* Fix readme after changes in usage ([`dea8b91`](https://github.com/F-Secure/pytest-rts/commit/dea8b91925ee11d55b3fa266cd3b2081484511f1))
* Aligned commit types with commit checker ([`3a865de`](https://github.com/F-Secure/pytest-rts/commit/3a865de642a95ab029719cac1104beba2c0857f3))
* Add performance section to changelog ([`b7f6139`](https://github.com/F-Secure/pytest-rts/commit/b7f6139520350c6f3ff49c1d5451b7d2015c5b56))
* Added Acknowledgement section to README.md ([#75](https://github.com/F-Secure/pytest-rts/issues/75)) ([`4de6632`](https://github.com/F-Secure/pytest-rts/commit/4de663291fd8c388164259b830e4badcb13d98e8))
* Added link to the tutorial to README.md and fixed usage sectino ([`9d25edf`](https://github.com/F-Secure/pytest-rts/commit/9d25edf7c54c2e0b7743cc83c5c8e7e658c88118))
* Fix module name in setup.py ([`7f18303`](https://github.com/F-Secure/pytest-rts/commit/7f183036384bccd45fb93203a26a0ae3198b80e3))
* Added license ([`ebfdd66`](https://github.com/F-Secure/pytest-rts/commit/ebfdd6624606201976df03463248106cfdb5b964))
* Update docs to match usage with plugin ([#68](https://github.com/F-Secure/pytest-rts/issues/68)) ([`d98f19a`](https://github.com/F-Secure/pytest-rts/commit/d98f19aebff37b4a20946a5438bf11888a86b6b1))
* Improved sequence diagrams ([#64](https://github.com/F-Secure/pytest-rts/issues/64)) ([`c558438`](https://github.com/F-Secure/pytest-rts/commit/c5584386897f0c100ed5f26db0d5fd28bc2f76b7))
* Added sequence diagrams, fixed links ([#59](https://github.com/F-Secure/pytest-rts/issues/59)) ([`84edc4e`](https://github.com/F-Secure/pytest-rts/commit/84edc4e2f3e87e762114801c0f63ce2d155e6cf2))
* Added common docs, fixed README.md ([#51](https://github.com/F-Secure/pytest-rts/issues/51)) ([`6240861`](https://github.com/F-Secure/pytest-rts/commit/6240861f8da7ed1895940d1171ecc56067e9ea5c))
* Scaled up logo a bit ([`c58c829`](https://github.com/F-Secure/pytest-rts/commit/c58c8299e2b10d87db6f456cabe17dfc6d4bb955))
* Added vector logo ([`379379b`](https://github.com/F-Secure/pytest-rts/commit/379379bf4538f3cb74c9abab1c29892a1a03235f))
* Added logo ([#43](https://github.com/F-Secure/pytest-rts/issues/43)) ([`f080cd2`](https://github.com/F-Secure/pytest-rts/commit/f080cd2a1658ba7ee04b7b6e53b28339ffcc6db3))

## v1.2.1 (2021-03-03)
### Fix
* Fix crash in test function runtimes ([`ad4c1f3`](https://github.com/F-Secure/pytest-rts/commit/ad4c1f3820a72bf2b9cbc8583c94bba6d2b2dcc2))

## v1.2.0 (2021-02-15)
### Feature
* Handle usage in non-git directory ([`8ad080b`](https://github.com/F-Secure/pytest-rts/commit/8ad080be7eb31b96e1047a4aadabe9fe1a944085))

### Documentation
* Add performance section to changelog ([`b7f6139`](https://github.com/F-Secure/pytest-rts/commit/b7f6139520350c6f3ff49c1d5451b7d2015c5b56))

## v1.1.10 (2021-01-29)
### Fix
* Rename selection file to prevent test discovery ([`b80f30a`](https://github.com/F-Secure/pytest-rts/commit/b80f30a6e29060f1b9769d01ec61760a49d2f977))

### Documentation
* Added Acknowledgement section to README.md ([#75](https://github.com/F-Secure/pytest-rts/issues/75)) ([`4de6632`](https://github.com/F-Secure/pytest-rts/commit/4de663291fd8c388164259b830e4badcb13d98e8))
* Added link to the tutorial to README.md and fixed usage sectino ([`9d25edf`](https://github.com/F-Secure/pytest-rts/commit/9d25edf7c54c2e0b7743cc83c5c8e7e658c88118))

### Performance

#### Mapping database initialization for RTS

   | Pytest run of "pandas/tests/arithmetic/" of [Pandas](https://github.com/pandas-dev/pandas) (Commit 3bd3d1ec253a8a18ac951511820eb970f62baaed, 11839 tests)        | normal run | [Coverage.py](https://github.com/nedbat/coveragepy) "dynamic context" |  pytest-rts 1.1.10 |
   | ------------------- | ------------------| ----------------| -----------------| 
   | Database size       | -           | 2.8 MB         |  307 MB         |
   | Runtime | 2min 5s            | 4min 36s         |  5min 36s        |

## v1.1.9 (2020-12-21)
### Fix
* Minor ([`891c743`](https://github.com/F-Secure/pytest-rts/commit/891c743332cf7c5248f6ec1b28140c4381a72ef6))

### Performance

#### Mapping database initialization for RTS

   | Pytest run of "pandas/tests/arithmetic/" of [Pandas](https://github.com/pandas-dev/pandas) (Commit 3bd3d1ec253a8a18ac951511820eb970f62baaed, 11839 tests)        | normal run | [Coverage.py](https://github.com/nedbat/coveragepy) "dynamic context" | pytest-rts 1.1.9  |
   | ------------------- | ------------------| ----------------| -----------------| 
   | Database size       | -           | 2.8 MB         | 307 MB         | 
   | Runtime | 2min 5s            | 4min 36s         | 2h 24min 7s         |

## v1.1.8 (2020-12-21)
### Fix
* Pypi long description ([`efb1c37`](https://github.com/F-Secure/pytest-rts/commit/efb1c3734f4b04f1e2e3dd6d677957fbe2507a4c))

## v1.1.7 (2020-12-21)
### Fix
* Pypi upload ([`f82e20c`](https://github.com/F-Secure/pytest-rts/commit/f82e20c43ec2936531e7a661560e8e98f089f164))

## v1.1.6 (2020-12-21)
### Fix
* Pypi upload ([`537d270`](https://github.com/F-Secure/pytest-rts/commit/537d2706a599455e40e6836b4bd3a308ae36160b))

## v1.1.5 (2020-12-21)
### Fix
* Pypi upload ([`d7778c8`](https://github.com/F-Secure/pytest-rts/commit/d7778c8b23777411b288af2a739e0f3e3ab3b7e6))

## v1.1.4 (2020-12-21)
### Fix
* Pypi upload ([`0f7339c`](https://github.com/F-Secure/pytest-rts/commit/0f7339c54dee32595280b42b118f06145067c29f))

## v1.1.3 (2020-12-21)
### Fix
* Merge branch 'master' of github.com:F-Secure/pytest-rts ([`97ab69d`](https://github.com/F-Secure/pytest-rts/commit/97ab69de2ce6447b638978017ba74a3ab9db94c8))
* Pypi upload ([`c6ba5bc`](https://github.com/F-Secure/pytest-rts/commit/c6ba5bc66c4969ea9f432b275c209a26a7d2c2cf))

## v1.1.2 (2020-12-21)
### Fix
* Pypi upload ([`7cde1be`](https://github.com/F-Secure/pytest-rts/commit/7cde1be414b980ecb5fb45eac24d7696aacf0b28))

### Documentation
* Fix module name in setup.py ([`7f18303`](https://github.com/F-Secure/pytest-rts/commit/7f183036384bccd45fb93203a26a0ae3198b80e3))
* Added license ([`ebfdd66`](https://github.com/F-Secure/pytest-rts/commit/ebfdd6624606201976df03463248106cfdb5b964))

## v1.1.1 (2020-12-18)
### Fix
* Linter errors ([`b0f2ac0`](https://github.com/F-Secure/pytest-rts/commit/b0f2ac04937d3a36ba9697001949fb9cc12946c9))

## v1.1.0 (2020-12-18)
### Feature
* Create a pytest plugin ([#67](https://github.com/F-Secure/pytest-rts/issues/67)) ([`1ed34e3`](https://github.com/F-Secure/pytest-rts/commit/1ed34e3f6591f627f93dbacad213236f08237258))

### Fix
* Track code in __init__.py files ([`ab89c7b`](https://github.com/F-Secure/pytest-rts/commit/ab89c7b9eb98435c0ab00cf1a43393f907126743))

### Documentation
* Update docs to match usage with plugin ([#68](https://github.com/F-Secure/pytest-rts/issues/68)) ([`d98f19a`](https://github.com/F-Secure/pytest-rts/commit/d98f19aebff37b4a20946a5438bf11888a86b6b1))
* Improved sequence diagrams ([#64](https://github.com/F-Secure/pytest-rts/issues/64)) ([`c558438`](https://github.com/F-Secure/pytest-rts/commit/c5584386897f0c100ed5f26db0d5fd28bc2f76b7))
* Added sequence diagrams, fixed links ([#59](https://github.com/F-Secure/pytest-rts/issues/59)) ([`84edc4e`](https://github.com/F-Secure/pytest-rts/commit/84edc4e2f3e87e762114801c0f63ce2d155e6cf2))
* Added common docs, fixed README.md ([#51](https://github.com/F-Secure/pytest-rts/issues/51)) ([`6240861`](https://github.com/F-Secure/pytest-rts/commit/6240861f8da7ed1895940d1171ecc56067e9ea5c))
* Scaled up logo a bit ([`c58c829`](https://github.com/F-Secure/pytest-rts/commit/c58c8299e2b10d87db6f456cabe17dfc6d4bb955))
* Added vector logo ([`379379b`](https://github.com/F-Secure/pytest-rts/commit/379379bf4538f3cb74c9abab1c29892a1a03235f))
* Added logo ([#43](https://github.com/F-Secure/pytest-rts/issues/43)) ([`f080cd2`](https://github.com/F-Secure/pytest-rts/commit/f080cd2a1658ba7ee04b7b6e53b28339ffcc6db3))
